@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2007-2008 John-Paul Stanford <jp@stanwood.org.uk>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007-2008 John-Paul Stanford <jp@stanwood.org.uk>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
 #ifndef BOARD_H
 #define BOARD_H
 
@@ -24,7 +13,7 @@
 #include <QQueue>
 #include <QSize>
 
-// KDE
+// KDEGames
 #include <KGameRenderer>
 
 class Plane;
@@ -48,7 +37,7 @@ public:
      */
     explicit BomberBoard(KGameRenderer * renderer, QGraphicsView * view, QObject * parent = nullptr);
 
-    ~BomberBoard();
+    ~BomberBoard() override;
 
     /**
      * This is called when the game board is resized
